@@ -1,6 +1,6 @@
 package Data::SearchEngine::Query;
 {
-  $Data::SearchEngine::Query::VERSION = '0.25';
+  $Data::SearchEngine::Query::VERSION = '0.26';
 }
 use Moose;
 use MooseX::Storage;
@@ -21,6 +21,13 @@ has count => (
 );
 
 
+has debug => (
+    is => 'rw',
+    isa => 'Str',
+    predicate => 'has_debug'
+);
+
+
 has facets => (
     traits => [ 'Hash', 'Digestable' ],
     is => 'rw',
@@ -143,7 +150,7 @@ Data::SearchEngine::Query - Query to pass to an engine.
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 DESCRIPTION
 
@@ -161,6 +168,13 @@ L<Data::SearchEngine::Meta::Attribute::Trait::Digestable>.
 
 The number of results this query should return.
 
+=head2 debug
+
+A string value denoting that this query should include debugging information
+in the response.  Uses a string as the type because some search indexes
+allow you to specify the type of debugging.  For those that just use a flag,
+the predicate should be checked so that any true value results in debugging.
+
 =head2 facets
 
 A HashRef of facets used with the query.  The key should be the facet name and
@@ -208,6 +222,10 @@ query type, if specified.
 
 =head1 METHODS
 
+=head2 has_debug
+
+Returns true if this Query has a value for debug.
+
 =head2 facet_names
 
 Get the names of all facets.
